import numpy as np
from easy_logs import get_logger

logger = get_logger(lvl=10)


def _get_all_squares_at_the_diagonal(square: int, position_length: int) -> list[int]:
    """
    [[up-right],  [up-left],[down-right], [down-left]]
    It was hard to write, so it should be hard to read.
    No comment for you.
    """
    size = int(np.sqrt(position_length * 2))
    row_idx = {val: val // (size // 2) for val in range(position_length + 1)}
    result = []
    squares, sq = [], square

    while (sq) % size != ((size // 2) - 1) and sq >= (size // 2):  # up right
        sq = (sq - (size // 2)) + (row_idx[sq] + 1) % 2
        squares.append(sq)
    result.append(list(squares))
    squares, sq = [], square

    while (sq) % size != (size // 2) and sq >= (size // 2):  # up left
        sq = (sq - ((size // 2) + 1)) + (row_idx[sq] + 1) % 2
        squares.append(sq)
    result.append(list(squares))
    squares, sq = [], square

    while (sq) % size != ((size // 2) - 1) and sq < position_length - (
        size // 2
    ):  # down right
        sq = sq + ((size // 2) + 1) - (row_idx[sq]) % 2
        squares.append(sq)
    result.append(list(squares))
    squares, sq = [], square

    while (sq) % size != (size // 2) and sq < position_length - (
        size // 2
    ):  # down left
        sq = sq + (size // 2) - (row_idx[sq]) % 2
        squares.append(sq)
    result.append(list(squares))
    return result


def get_king_pseudo_legal_moves(position_length: int) -> dict[list]:
    squares = {}
    for sq in range(position_length):
        squares[sq] = _get_all_squares_at_the_diagonal(sq, position_length)
    return squares


def get_man_pseudo_legal_moves(position_length: int) -> dict[list]:
    squares = {}
    for sq in range(position_length):
        squares[sq] = [
            moves[:2] for moves in _get_all_squares_at_the_diagonal(sq, position_length)
        ]
    return squares



from __future__ import annotations

from typing import Generator

from draughts.models import Figure


class Move:
    """Move representation.
    End user should never interact with this class directly.

    As we can read on wikipedia:

    *Multiple jumps, such as a double or triple jump,
    require you to pay attention, as the convention is
    to just show the start and end squares and not the
    in-between or intermediate squares. So the notation
    1-3 would mean a King does a double jump from 1 to 10 to 3.
    The intermediate square is only shown if there are two ways
    to jump and it would not be clear otherwise.*

    Note that always:
    n - number of visited squares (include source square)
    n - 2 - number of captured pieces
    """

    def __init__(
        self,
        visited_squares: list[int],
        captured_list: list[int] = [],
        captured_entities: list[Figure.value] = [],
        is_promotion: bool = False,
    ) -> None:
        self.square_list = visited_squares
        self.captured_list = captured_list
        self.captured_entities = captured_entities
        self.is_promotion = is_promotion

    def __repr__(self) -> str:
        visited_squares = [str(s + 1) for s in self.square_list]
        return f"Move: {'->'.join(visited_squares)}"

    def __eq__(self, other: object) -> bool:
        """Check if two moves are equal. move created from string will have only visited squares definied."""
        if not isinstance(other, Move):
            return False

        if (
            self.square_list[0] == other.square_list[0]
            and self.square_list[-1] == other.square_list[-1]
        ):
            longer = (
                self.square_list
                if len(self.square_list) >= len(other.square_list)
                else other.square_list
            )
            shorter = (
                self.square_list
                if len(self.square_list) < len(other.square_list)
                else other.square_list
            )

            return all(square in longer for square in shorter)

        return False

    def __len__(self) -> int:
        return len(self.captured_list) + 1

    def __add__(self, other: Move) -> Move:
        """Append moves"""
        if self.square_list[-1] != other.square_list[0]:
            raise ValueError(
                f"Cannot append moves {self} and {other}. Last square of first move should be equal to first square of second move."
            )
        return Move(
            self.square_list + other.square_list[1:],
            self.captured_list + other.captured_list,
            self.captured_entities + other.captured_entities,
        )

    @classmethod
    def from_string(cls, move: str, legal_moves: Generator) -> Move:
        """

        Converts string representation of move to ``Move`` object.
        This is generic method, so it can be used for any board size. Therefore,
        For different context different move object will be generated.
        Also we need to pass legal moves, to understand given move and check if it is legal.


        input format:

        * ``<square_number>-<square_number>`` for simple move
        * ``<square_number>x<square_number>`` for capture

        Examples:

        * ``24-19`` - means from 24 to 19
        * ``24x19`` - means from 24 to 16 means capture of piece between 24 and 16
        * ``1x10x19`` - means capture of two pieces between 1 and 19

        """
        move = move.lower()
        if "-" in move:  # classic move
            steps = move.split("-")
        elif "x" in move:  # this means capture
            steps = move.split("x")
        else:
            raise ValueError(f"Invalid move {move}.")

        move = Move([int(step) - 1 for step in steps])
        for legal_move in legal_moves:
            if legal_move == move:
                return legal_move
        raise ValueError(
            f"{move} is correct, but not legal in given position.\n Legal moves are: {list(legal_moves)}"
        )



import numpy as np
import pytest

import draughts.american as checkers
from draughts.american import Board, Color, Move
from draughts.models import Figure


class TestAmericanBoard:
    @pytest.fixture(autouse=True)
    def setup(self):
        self.board = Board()
        yield
        del self.board

    def test_move_from_str_method(self):
        legal_moves = self.board.legal_moves
        m1 = Move.from_string("24-20", legal_moves)
        assert m1 == Move([checkers.G3, checkers.H4])

        with pytest.raises(ValueError):
            Move.from_string("25-20", [])

    def test_push_from_string(self):
        m1 = Move.from_string("24-20", self.board.legal_moves)
        self.board.push_from_str("24-20")
        assert self.board.turn == Color.BLACK
        assert self.board.pop() == m1
        assert np.array_equal(self.board.position, Board.STARTING_POSITION)

    def test_capture(self):
        moves = ["24-20", "11-16", "20x11", "7x16"]
        for m in moves:
            self.board.push_from_str(m)
        assert self.board[checkers.F6] == Figure.EMPTY.value



from __future__ import annotations

from enum import Enum, IntEnum
from typing import NewType

import numpy as np

STARTING_POSITION = np.array([1] * 12 + [0] * 8 + [-1] * 12, dtype=np.int8)
SquareT = NewType("SquareT", int)


class Color(Enum):
    WHITE = -1
    BLACK = 1


class Figure(IntEnum):
    BLACK_KING = Color.BLACK.value * 2
    BLACK_MAN = Color.BLACK.value
    WHITE_KING = Color.WHITE.value * 2
    WHITE_MAN = Color.WHITE.value
    KING = 2
    MAN = 1
    EMPTY = 0


ENTITY_REPR = {
    Figure.BLACK_MAN: "b",
    Figure.WHITE_MAN: "w",
    Figure.EMPTY: ".",
    Figure.BLACK_KING: "B",
    Figure.WHITE_KING: "W",
}



import numpy as np
import pytest

import draughts.base as checkers
from draughts.base import BaseBoard, Color, Figure, Move


class TestBoard:
    @pytest.fixture(autouse=True)
    def setup(self):
        self.board = BaseBoard(BaseBoard.STARTING_POSITION)
        yield
        del self.board

    def test_init(self):
        assert self.board.turn == Color.WHITE
        assert np.array_equal(self.board.position, BaseBoard.STARTING_POSITION)

    def test_move(self):
        m = Move([checkers.A3, checkers.B4])
        self.board.push(m)
        assert self.board.turn == Color.BLACK
        assert self.board[checkers.A3] == Figure.EMPTY
        assert self.board[checkers.B4] == Figure.WHITE_MAN
        m = Move([checkers.F6, checkers.G5])
        self.board.push(m)
        assert self.board.turn == Color.WHITE
        assert self.board[checkers.F6] == Figure.EMPTY
        assert self.board[checkers.G5] == Figure.BLACK_MAN

    def test_capture(self):
        m1 = Move([checkers.C3, checkers.B4])
        self.board.push(m1)

        m2 = Move([checkers.B6, checkers.A5])
        self.board.push(m2)

        m3 = Move([checkers.G3, checkers.H4])
        self.board.push(m3)

        m4 = Move([checkers.A5, checkers.C3], captured_list=[checkers.B4])
        self.board.push(m4)

        assert self.board[checkers.B4] == Figure.EMPTY
        assert self.board[checkers.C3] == Figure.BLACK_MAN

        m5 = Move([checkers.B2, checkers.D4], captured_list=[checkers.C3])
        self.board.push(m5)
        assert self.board[checkers.B2] == Figure.EMPTY
        assert self.board[checkers.C3] == Figure.EMPTY
        assert self.board[checkers.D4] == Figure.WHITE_MAN

    def test_pop(self):
        m = Move([checkers.A3, checkers.B4])
        self.board.push(m)
        assert self.board.turn == Color.BLACK
        assert self.board[checkers.A3] == Figure.EMPTY
        assert self.board[checkers.B4] == Figure.WHITE_MAN
        m = Move([checkers.F6, checkers.G5])
        self.board.push(m)
        self.board.pop()
        assert self.board.turn == Color.BLACK
        assert self.board[checkers.F6] == Figure.BLACK_MAN
        assert self.board[checkers.G5] == Figure.EMPTY
        assert self.board[checkers.A3] == Figure.EMPTY
        assert self.board[checkers.B4] == Figure.WHITE_MAN



import json
from collections import defaultdict
from pathlib import Path
from typing import Literal

import numpy as np
import uvicorn
from fastapi import APIRouter, FastAPI, Request
from fastapi.responses import RedirectResponse
from fastapi.staticfiles import StaticFiles
from fastapi.templating import Jinja2Templates
from pydantic import BaseModel, Field

from draughts import __version__
from draughts.base import BaseBoard, Color
from draughts.standard import Board


class PositionResponse(BaseModel):
    position: list = Field(description="Current board position")
    history: list = Field(description="History of moves")
    turn: Literal["white", "black"] = Field(description="Current turn")


class Server:
    APP = FastAPI(title="py-draughts", version=__version__)
    static_dir = Path(__file__).parent / "static"
    APP.mount("/static", StaticFiles(directory=static_dir), name="static")
    templates_dir = Path(__file__).parent / "templates"
    templates = Jinja2Templates(directory=templates_dir)

    def __init__(
        self,
        board: BaseBoard = Board(),
        get_best_move_method: callable = None,
    ):
        self.get_best_move_method = get_best_move_method
        self.board = board
        self.router = APIRouter()
        self.router.add_api_route("/", self.index)
        self.router.add_api_route(
            "/set_board/{board_type}", self.set_board, methods=["GET"]
        )
        self.router.add_api_route("/legal_moves", self.get_legal_moves, methods=["GET"])
        self.router.add_api_route("/fen", self.get_fen, methods=["GET"])
        self.router.add_api_route(
            "/set_random_position", self.set_random_position, methods=["GET"]
        )
        self.router.add_api_route("/best_move", self.get_best_move, methods=["GET"])
        self.router.add_api_route("/position", self.get_position, methods=["GET"])
        self.router.add_api_route(
            "/move/{source}/{target}", self.move, methods=["POST"]
        )
        self.router.add_api_route("/pop", self.pop, methods=["GET"])
        self.APP.include_router(self.router)
        if not get_best_move_method:
            self.get_best_move_method = lambda board: np.random.choice(
                list(board.legal_moves)
            )

    def get_fen(self):
        return {"fen": self.board.fen}

    def set_board(self, request: Request, board_type: Literal["standard", "american"]):
        if board_type == "standard":
            from draughts.standard import Board

            self.board = Board()
        elif board_type == "american":
            from draughts.american import Board

            self.board = Board()

        return RedirectResponse(url="/")

    def get_legal_moves(self):
        moves_dict = defaultdict(list)
        for move in list(self.board.legal_moves):
            moves_dict[int(move.square_list[0])].extend(map(int, move.square_list[1:]))
        return {
            "legal_moves": json.dumps(moves_dict),
        }

    @property
    def position_json(self) -> PositionResponse:
        history = []  # (numver, white, black)
        stack = self.board._moves_stack
        for idx in range(len(stack)):
            src, tg = stack[idx].square_list[0] + 1, stack[idx].square_list[-1]
            if idx % 2 == 0:
                history.append([(idx // 2) + 1, f"{src}-{tg}"])
            else:
                history[-1].append(f"{src}-{tg}")
        turn = "white" if self.board.turn == Color.WHITE else "black"
        return PositionResponse(
            position=self.board.friendly_form.tolist(),
            history=history,
            turn=turn,
        )

    def get_position(self, request: Request) -> PositionResponse:
        return self.position_json

    def set_random_position(self, request: Request) -> PositionResponse:
        STARTING_POSITION = np.random.choice(
            [2, 0, -2, 1, -1],
            size=len(self.board.STARTING_POSITION),
            replace=True,
            p=[0.1, 0.6, 0.1, 0.1, 0.1],
        )
        self.board._moves_stack = []
        self.board._pos = STARTING_POSITION
        return self.position_json

    def get_best_move(self, request: Request) -> PositionResponse:
        move = self.get_best_move_method(self.board)
        self.board.push(move)
        return self.position_json

    def move(self, request: Request, source: str, target: str) -> PositionResponse:
        move_str = f"{source}-{target}"
        self.board.push_from_str(move_str)
        return self.position_json

    def pop(self, request: Request) -> PositionResponse:
        self.board.pop()
        return self.position_json

    def index(self, request: Request):
        return self.templates.TemplateResponse(
            "index.html",
            {
                "request": request,
                "size": len(self.board.STARTING_POSITION) * 2,
            },
        )

    def run(self, **kwargs):
        uvicorn.run(self.APP, **kwargs)


if __name__ == "__main__":
    from draughts.standard import Board

    server = Server(
        get_best_move_method=lambda board: np.random.choice(list(board.legal_moves)),
    )
    server.run()



from __future__ import annotations

from typing import Generator

import numpy as np

from draughts.base import BaseBoard
from draughts.models import Color, Figure
from draughts.move import Move

# fmt: off
SQUARES = [B8, D8, F8, H8,
        A7, C7, E7, G7,
        B6, D6, F6, H6,
        A5, C5, E5, G5,
        B4, D4, F4, H4,
        A3, C3, E3, G3,
        B2, D2, F2, H2,
        A1, C1, E1, G1] = range(32)
# fmt: on


class Board(BaseBoard):
    """
    **Board for American checkers.**
     Game rules:

     - Board size: 8x8
     - Short moves only
     - Only the king can capture backwards
     - Capture - choose any
    """

    GAME_TYPE = 23
    STARTING_POSITION = np.array([1] * 12 + [0] * 8 + [-1] * 12, dtype=np.int8)
    VARIANT_NAME = "American checkers"
    size = int(np.sqrt(len(STARTING_POSITION) * 2))
    row_idx = {val: val // 4 for val in range(len(STARTING_POSITION))}
    col_idx = {val: val % 8 for val in range(len(STARTING_POSITION))}

    def __init__(self, starting_position=STARTING_POSITION) -> None:
        super().__init__(starting_position)

    @property
    def legal_moves(self) -> Generator[Move, None, None]:
        if self.turn == Color.BLACK:
            squares_list = np.transpose(np.nonzero(self._pos > 0))
        else:
            squares_list = np.transpose(np.nonzero(self._pos < 0))
        for square in squares_list.flatten():
            moves = self._legal_moves_from(square)
            for move in moves:
                yield move

    def _legal_moves_from(
        self, square: int, is_after_capture=False
    ) -> Generator[Move, None, None]:
        row = self.row_idx[square]
        moves = []
        odd = bool(row % 2 != 0 and self.turn == Color.BLACK) or (
            row % 2 == 0 and self.turn == Color.WHITE
        )
        is_king = bool(self[square] == self.turn.value * Figure.KING)
        # is_king = False  # DEBUG
        for mv_offset, cap_offset, dir in [
            (4 - odd, 7, self.turn.value),
            (5 - odd, 9, self.turn.value),
        ] + is_king * [
            (4 - (not odd), 7, -self.turn.value),
            (5 - (not odd), 9, -self.turn.value),
        ]:
            move_sq = square + mv_offset * (dir)
            capture_sq = square + cap_offset * (dir)

            if (
                0 <= move_sq < len(self._pos)
                and row + 1 * (dir) == self.row_idx[move_sq]
                and self[move_sq] == 0
                and not is_after_capture
            ):
                moves.append(Move([square, move_sq]))
            elif (
                0 <= capture_sq < len(self._pos)
                and row + 2 * (dir) == self.row_idx[capture_sq]
                and self[capture_sq] == 0
                and self[move_sq] * self.turn.value < 0
            ):
                move = Move(
                    [square, capture_sq],
                    captured_list=[move_sq],
                    captured_entities=[self[move_sq]],
                )
                moves.append(move)
                self.push(move, False)
                moves += [move + m for m in self._legal_moves_from(capture_sq, True)]
                self.pop(False)

        return moves


if __name__ == "__main__":
    board = Board()
    print(list(board.legal_moves))
    # board.push_from_str("12-16")
    # board.push_from_str("12-16")
    # board.push_from_str("23-18")
    # board.push_from_str("16-23")
    # print(board.pop())
    print(board)
    # while True:
    #     moves = board.legal_moves
    #     move = np.random.choice(list(moves))
    #     board.push(move)
    #     print(move)
    #     print(board)
    #     from time import sleep

    #     sleep(2)



# This file is part of the py-draughts library.
# Copyright (C) 2023-2023 Michał Skibiński
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""
A draughts library with advenced (customizable) WEB UI move generation and validation,
PDN parsing and writing. Supports multiple variants of game.
"""

from typing import Literal

__version__ = "1.1.0"
__author__ = "Michał Skibiński"


def get_board(variant: Literal["standard", "american"], fen: str = None):
    """
    Board factory method.
    - ``standard`` - standard draughts board
    - ``american`` - american checkers board
    """
    from draughts.american import Board as AmericanBoard
    from draughts.base import BaseBoard
    from draughts.standard import Board as StandardBoard

    BOARDS = {
        "standard": StandardBoard,
        "american": AmericanBoard,
    }
    board_cls: BaseBoard = BOARDS[variant]
    if fen:
        return board_cls.from_fen(fen)
    return board_cls()



from __future__ import annotations

import numpy as np

from draughts.base import BaseBoard
from draughts.models import Figure
from draughts.move import Move
from draughts.utils import (get_king_pseudo_legal_moves,
                            get_man_pseudo_legal_moves)

# fmt: off
SQUARES=  [ B10, D10, F10, H10, J10,
            A9, C9, E9, G9, I9,
            B8, D8, F8, H8, J8, 
            A7, C7, E7, G7, I7,
            B6, D6, F6, H6, J6,
            A5, C5, E5, G5, I5,
            B4, D4, F4, H4, J4,
            A3, C3, E3, G3, I3,
            B2, D2, F2, H2, J2,
            A1, C1, E1, G1, I1] = range(50)
# fmt: on


class Board(BaseBoard):
    """
    **Board for Standard (international) checkers.**
     Game rules:

     - Board size: 10x10
     - Any piece can capture backwards and forwards
     - Capture is mandatory
     - King can move along the diagonal any number of squares
    """

    GAME_TYPE = 20
    STARTING_POSITION = np.array([1] * 15 + [0] * 20 + [-1] * 15, dtype=np.int8)
    PSEUDO_LEGAL_KING_MOVES = get_king_pseudo_legal_moves(len(STARTING_POSITION))
    PSEUDO_LEGAL_MAN_MOVES = get_man_pseudo_legal_moves(len(STARTING_POSITION))

    def __init__(self, starting_position=STARTING_POSITION) -> None:
        super().__init__(starting_position)

    @property
    def legal_moves(self) -> list[Move]:
        all_moves = []
        is_capture_mandatory = False
        squares_list = np.transpose(np.nonzero(self._pos * self.turn.value > 0))
        for square in squares_list.flatten():
            moves = self._legal_moves_from(square, is_capture_mandatory)
            # if not is_capture_mandatory and any( # TODO this should optimize the search
            #     [len(move.square_list) > 0 for move in moves]
            # ):
            #     is_capture_mandatory = True
            all_moves.extend(moves)
        if any([len(move.captured_list) > 0 for move in all_moves]):
            all_moves = [move for move in all_moves if len(move.captured_list) > 0]
        return all_moves

    def _get_man_legal_moves_from(
        self, square: int, is_capture_mandatory: bool
    ) -> list:
        moves = []
        # white can move only on even directions
        for idx, direction in enumerate(self.PSEUDO_LEGAL_MAN_MOVES[square]):
            if (
                len(direction) > 0
                and (self.turn.value + idx)
                in [-1, 0, 3, 4]  # TERRIBLE HACK get only directions for given piece
                and self._pos[direction[0]] == Figure.EMPTY
                and not is_capture_mandatory
            ):
                moves.append(Move([square, direction[0]]))
            elif (
                len(direction) > 1
                and self._pos[direction[0]] * self.turn.value < 0
                and self._pos[direction[1]] == Figure.EMPTY
            ):
                move = Move(
                    [square, direction[1]], [direction[0]], [self._pos[direction[0]]]
                )
                moves.append(move)
                self.push(move, False)
                moves += [move + m for m in self._legal_moves_from(direction[1], True)]
                self.pop(False)
        return moves

    def _get_king_legal_moves_from(
        self, square: int, is_capture_mandatory: bool
    ) -> list[Move]:
        moves = []
        for direction in self.PSEUDO_LEGAL_KING_MOVES[square]:
            for idx, target in enumerate(direction):
                if (
                    len(direction) > idx + 1
                    and self._pos[target] * self.turn.value < 0
                    and self._pos[direction[idx + 1]] == Figure.EMPTY
                ):
                    i = idx + 1
                    while (
                        i < len(direction) and self._pos[direction[i]] == Figure.EMPTY
                    ):
                        move = Move(
                            [square, direction[i]], [target], [self._pos[target]]
                        )
                        moves.append(move)
                        self.push(move, False)
                        moves += [
                            move + m for m in self._legal_moves_from(direction[i], True)
                        ]
                        # if one move is longer then others return only this one
                        self.pop(False)
                        max_len = max([len(m) for m in moves])
                        moves = [m for m in moves if len(m) == max_len]
                        i += 1
                    break
                if (
                    self._pos[target] == Figure.EMPTY.value and not is_capture_mandatory
                ):  # casual move
                    moves.append(Move([square, target]))
                else:
                    break
        return moves

    def _legal_moves_from(self, square: int, is_capture_mandatory=False) -> list[Move]:
        entity = Figure(self._pos[square])
        if abs(entity) == Figure.MAN:
            moves = self._get_man_legal_moves_from(square, is_capture_mandatory)
        else:
            moves = self._get_king_legal_moves_from(square, is_capture_mandatory)
        if is_capture_mandatory:
            moves = [move for move in moves if len(move.captured_list) > 0]
        return moves


if __name__ == "__main__":
    board = Board()

    b = Board.from_fen("B:B:WG8,18,24,28,34,37,42,44,49:B2,10,12,15,25,26")
    print(b)
    Board.from_fen("W:W4,11,28,31,K33,K34,38,40,K41,43,K44,45,K46,47:BK3,21,27,32")



from pathlib import Path

import setuptools

from draughts.__init__ import __doc__, __version__

this_directory = Path(__file__).parent
long_description = (this_directory / "readme.md").read_text()

with open(this_directory / "requirements.txt") as f:
    requirements = f.read().splitlines()


setuptools.setup(
    name="py-draughts",
    install_requires=requirements,
    version=__version__,
    author="Michał Skibiński",
    author_email="mskibinski109@gmail.com",
    description=__doc__.replace("\n", " ").strip(),
    long_description=long_description,
    # rst
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    package_data={"draughts": ["static/js/*", "static/css/*", "templates/*"]},
    license="GPL-3.0+",
    keywords=" draughts, checkers, AI mini-max, game, board",
    url="https://github.com/michalskibinski109/draughts",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Topic :: Games/Entertainment :: Board Games",
        "Topic :: Games/Entertainment :: Turn Based Strategy",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Typing :: Typed",
    ],
    project_urls={
        "Documentation": "https://michalskibinski109.github.io/py-draughts/index.html",
    },
    python_requires=">=3.7",
)
